==> by0websitegenerator-5.0.0.tar.gz: by0websitegenerator-5.0.0/README.md <==
<p align="center">
    <a href="https://byzero.dev/copyright">
        <img src="https://raw.githubusercontent.com/byZeroOfficial/WebsiteGenerator/main/brand/Logo.png" width="350" />
    </a>
</p>
<p align="center">
    <i>With WebsiteGenerator you can easily generate web pages in the terminal.</i>
</p>
<p align="center">
   <b><a href="https://generator.byzero.dev/image-codes">Browse the icons on our website</a></b> • <b><a href="https://github.com/byZeroOfficial/WebsiteGenerator/issues">Get help</a></b>
</p>

<p align="center">
    <i><b>Make a issue</b> if you want to request a new icon.</i>

## Run Locally

1. [Download the latest version](https://github.com/byZeroOfficial/WebsiteGenerator/releases/latest/download/WebsiteGenerator.zip)
2. Install Python
3. In the ./src/ Folder, run
```
python main.py 
```
4. It should work.





## Demo

https://demo.generator.byzero.dev/


## Documentation

You can find documentation on how to install Python and what image codes are available [here](https://generator.byzero.dev).



## Icons
<p align="center">
    <i>The new image codes allow you to easily find icons for the cards and the social media icons.</i>
</p>
<p align="center">
   <b><a href="https://generator.byzero.dev/image-codes">Browse the icons on our website</a></b>
</p>

### Credits
- Some Images used are by https://solo.to.
- xmpp-Logo by https://github.com/xmpp-ftw/logo.
- session-Logo by the Official Repository: https://by0.link/D8k8Fw
- Generic-Icons by [aegis-icons](https://aegis-icons.github.io/)
## Used By
This project is used by:

    https://adb.sh/chat
    https://byzero.dev/chat
    https://edwinproking.ml

Create a Pull Request, so I can add your Website!

## Disclaimer
Before you use an icon, make sure you are not breaking any laws, design/trademark guidelines or licenses. **I have never had any problems with it.**
If you're owner of certain trademark(s) and want icon taken down for whatever reason, please [contact me](mailto:mail@byzero.dev).
Also, make sure to use an imprint for your website.

==> by0websitegenerator-5.0.1.tar.gz: by0websitegenerator-5.0.1/README.md <==
<p align="center">
    <a href="https://byzero.dev/copyright">
        <img src="https://raw.githubusercontent.com/byZeroOfficial/WebsiteGenerator/main/brand/Logo.png" width="350" />
    </a>
</p>
<p align="center">
    <i>With WebsiteGenerator you can easily generate web pages in the terminal.</i>
</p>
<p align="center">
   <b><a href="https://generator.byzero.dev/image-codes">Browse the icons on our website</a></b> • <b><a href="https://github.com/byZeroOfficial/WebsiteGenerator/issues">Get help</a></b>
</p>

<p align="center">
    <i><b>Make a issue</b> if you want to request a new icon.</i>

## Run via pip

1. Install Python and pip
2. Install it with 
```bash
pip install by0websitegenerator
```
3. Run
```bash
generatewebsite
``

## Run the standalone
1. [Download the latest version](https://github.com/byZeroOfficial/WebsiteGenerator/releases/latest/download/WebsiteGenerator.zip)
2. Install Python
3. In the ./src/ Folder, run
```
python main.py 
```
4. It should work.




## Demo

https://demo.generator.byzero.dev/


## Documentation

You can find documentation on how to install Python and what image codes are available [here](https://generator.byzero.dev).



## Icons
<p align="center">
    <i>The new image codes allow you to easily find icons for the cards and the social media icons.</i>
</p>
<p align="center">
   <b><a href="https://generator.byzero.dev/image-codes">Browse the icons on our website</a></b>
</p>

### Credits
- Some Images used are by https://solo.to.
- xmpp-Logo by https://github.com/xmpp-ftw/logo.
- session-Logo by the Official Repository: https://by0.link/D8k8Fw
- Generic-Icons by [aegis-icons](https://aegis-icons.github.io/)
## Used By
This project is used by:

    https://adb.sh/chat
    https://byzero.dev/chat
    https://edwinproking.ml

Create a Pull Request, so I can add your Website!

## Disclaimer
Before you use an icon, make sure you are not breaking any laws, design/trademark guidelines or licenses. **I have never had any problems with it.**
If you're owner of certain trademark(s) and want icon taken down for whatever reason, please [contact me](mailto:mail@byzero.dev).
Also, make sure to use an imprint for your website.
